@@ -36,7 +36,7 @@ in this Software without prior written authorization from the X Consortium.
  * used by all more than one of these dialogs.
  *
  * The following functions are the only non-static ones defined
- * in this module.  They are located at the begining of the
+ * in this module.  They are located at the beginning of the
  * section that contains this dialog box that uses them.
  *
  * void _XawTextInsertFileAction(w, event, params, num_params);
@@ -262,7 +262,7 @@ DoInsert(Widget w, XtPointer closure, XtPointer call_data)
  *	Description: Inserts a file into the text widget.
  *	Arguments: tw - The text widget to insert this file into.
  *                 str - name of the file to insert.
- *	Returns: TRUE if the insert was sucessful, FALSE otherwise.
+ *	Returns: TRUE if the insert was successful, FALSE otherwise.
  */
 
 
@@ -399,7 +399,7 @@ AddInsertFileChildren(Widget form, char *ptr, Widget tw)
  *
  * Note:
  *
- * If the search was sucessful and the argument popdown is passed to
+ * If the search was successful and the argument popdown is passed to
  * this action routine then the widget will automatically popdown the
  * search widget.
  */
@@ -481,7 +481,7 @@ SearchButton(Widget w, XtPointer closure, XtPointer call_data)
  * The parameter list contains one or two entries that may be the following.
  *
  * First Entry:   The first entry is the direction to search by default.
- *                This arguement must be specified and may have a value of
+ *                This argument must be specified and may have a value of
  *                "left" or "right".
  *
  * Second Entry:  This entry is optional and contains the value of the default
@@ -519,7 +519,7 @@ _XawTextSearch(Widget w, XEvent *event, String *params, Cardinal *num_params)
   else
 #ifdef XAW_INTERNATIONALIZATION
       if (_XawTextFormat(ctx) == XawFmtWide) {
-          /*This just does the equivalent of ptr = ""L, a waste because params[1] isnt W aligned.*/
+          /*This just does the equivalent of ptr = ""L, a waste because params[1] isn't W aligned.*/
           ptr = (char *)XtMalloc(sizeof(wchar_t));
           *((wchar_t*)ptr) = (wchar_t)0;
       } else
@@ -565,7 +565,7 @@ _XawTextSearch(Widget w, XEvent *event, String *params, Cardinal *num_params)
 
 /*	Function Name: InitializeSearchWidget
  *	Description: This function initializes the search widget and
- *                   is called each time the search widget is poped up.
+ *                   is called each time the search widget is popped up.
  *	Arguments: search - the search widget structure.
  *                 dir - direction to search.
  *                 replace_active - state of the sensitivity for the
@@ -777,8 +777,8 @@ AddSearchChildren(Widget form, char *ptr, Widget tw)
 
 /*	Function Name: DoSearch
  *	Description: Performs a search.
- *	Arguments: search - the serach structure.
- *	Returns: TRUE if sucessful.
+ *	Arguments: search - the search structure.
+ *	Returns: TRUE if successful.
  */
 
 /* ARGSUSED */
@@ -1111,7 +1111,7 @@ _SetField(Widget new, Widget old)
  *                 name - name of the child.
  *                 res_name - name of the resource.
  *                 value - the value of the resource.
- *	Returns: TRUE if sucessful.
+ *	Returns: TRUE if successful.
  */
 
 static Boolean
@@ -1245,7 +1245,7 @@ CenterWidgetOnPoint(Widget w, XEvent *event)
  *
  * NOTE:
  *
- * The function argument is passed the following arguements.
+ * The function argument is passed the following arguments.
  *
  * form - the from widget that is the dialog.
  * ptr - the initial string for the dialog's text widget.
